==> apache-cxf-3.5.10-src.zip: apache-cxf-3.5.10-src/rt/rs/microprofile-client/src/test/java/org/apache/cxf/microprofile/client/mock/HeadersFactoryClient.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.microprofile.client.mock;

import javax.ws.rs.GET;
import javax.ws.rs.HeaderParam;
import javax.ws.rs.Path;

import org.eclipse.microprofile.rest.client.annotation.ClientHeaderParam;
import org.eclipse.microprofile.rest.client.annotation.RegisterClientHeaders;

@RegisterClientHeaders(MyClientHeadersFactory.class)
@ClientHeaderParam(name = "IntfHeader1", value = "abc")
public interface HeadersFactoryClient {

    default String computeHeader(String headerName) {
        return "HeadersOnMethodClientValueFor" + headerName;
    }

    @ClientHeaderParam(name = "MethodHeader1", value = "def")
    @GET
    @Path("/")
    String get(@HeaderParam("HeaderParam1") String someValue);
}

==> apache-cxf-4.1.4-src.zip: apache-cxf-4.1.4-src/rt/rs/microprofile-client/src/test/java/org/apache/cxf/microprofile/client/mock/HeadersFactoryClient.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.microprofile.client.mock;

import jakarta.ws.rs.GET;
import jakarta.ws.rs.HeaderParam;
import jakarta.ws.rs.Path;
import org.eclipse.microprofile.rest.client.annotation.ClientHeaderParam;
import org.eclipse.microprofile.rest.client.annotation.RegisterClientHeaders;

@RegisterClientHeaders(MyClientHeadersFactory.class)
@ClientHeaderParam(name = "IntfHeader1", value = "abc")
public interface HeadersFactoryClient {

    default String computeHeader(String headerName) {
        return "HeadersOnMethodClientValueFor" + headerName;
    }

    @ClientHeaderParam(name = "MethodHeader1", value = "def")
    @GET
    @Path("/")
    String get(@HeaderParam("HeaderParam1") String someValue);
}
